.. _plotter-api-index:

Plotter API
===================================

This chapter is intended to describe data types that are used to assist in the plotting of density of states and band stucture.

PyProcar has the following data types:

- :class:`pyprocar.DOSPlot` is used to plot the density of states. 
    DOSPlot expects :class:`pyprocar.DensityOfStates` and :class:`pyprocar.Structure`

- :class:`pyprocar.EBSPlot` is used to plot the electronic band structure. 
    DOSPlot expects :class:`pyprocar.ElectronicBandStructure`


.. toctree::
    :maxdepth: 2

    bandsplot
    dosplot
    procarplot
    